pub enum AbiSubcommand {
Show 20 variants
CalldataEncode {
sig: String,
args: Vec<String>,
file: Option<PathBuf>,
},
DecodeCalldata {
sig: String,
calldata: Option<String>,
file: Option<PathBuf>,
},
DecodeString {
data: String,
},
DecodeEvent {
sig: Option<String>,
data: String,
},
DecodeError {
sig: Option<String>,
data: String,
},
DecodeAbi {
sig: String,
calldata: String,
input: bool,
},
AbiEncode {
sig: String,
packed: bool,
args: Vec<String>,
},
AbiEncodeEvent {
sig: String,
args: Vec<String>,
},
FourByte {
selector: Option<Selector>,
},
FourByteCalldata {
calldata: Option<String>,
},
FourByteEvent {
topic: Option<B256>,
},
UploadSignature {
signatures: Vec<String>,
},
PrettyCalldata {
calldata: Option<String>,
offline: bool,
},
CreationCode(CreationCodeArgs),
Artifact(ArtifactArgs),
ConstructorArgs(ConstructorArgsArgs),
Interface(InterfaceArgs),
Bind(BindArgs),
B2EPayload(B2EPayloadArgs),
Sig {
sig: Option<String>,
optimize: Option<usize>,
},
}Expand description
ABI encoding and decoding, selector and contract artifact subcommands.
Variants
CalldataEncode
ABI-encode a function with arguments.
Fields
DecodeCalldata
Decode ABI-encoded input data
Similar to abi-decode --input, but function selector MUST be prefixed in calldata.
Examples:
- cast decode-calldata “transfer(address,uint256)” $CALLDATA
- cast decode-calldata –json “transfer(address,uint256)” $CALLDATA
Fields
DecodeString
Decode ABI-encoded string.
Similar to calldata-decode --input, but the function argument is a string
DecodeEvent
Decode event data
Parameters marked indexed in the supplied signature are emitted as log topics rather than
data, so they are ignored when decoding. With --sig, DATA must contain only the encoded
non-indexed event data, without topics.
Examples:
- cast decode-event –sig “Transfer(address indexed from, address indexed to, uint256 value)” $DATA
- cast decode-event $DATA (topic0-prefixed data; looks up the signature)
Fields
sig: Option<String>The event signature. If none provided then tries to decode from local cache or https://4byte.sourcify.dev.
DecodeError
Decode custom error data.
Fields
sig: Option<String>The error signature. If none provided then tries to decode from local cache or https://4byte.sourcify.dev.
DecodeAbi
Decode ABI-encoded input or output data
Defaults to decoding output data. To decode input data pass –input.
When passing --input, function selector must NOT be prefixed in calldata string.
Examples:
- cast decode-abi “balanceOf(address)(uint256)” $DATA
- cast decode-abi –input “transfer(address,uint256)” $CALLDATA
Fields
AbiEncode
ABI encode the given function argument, excluding the selector
Examples:
- cast abi-encode “transfer(address,uint256)” $ADDRESS 100
- cast abi-encode –packed “f(string,uint64)” hello 100
Fields
AbiEncodeEvent
ABI encode an event and its arguments to generate topics and data.
FourByte
Get the function signatures for the given selector from https://4byte.sourcify.dev.
FourByteCalldata
Decode ABI-encoded calldata using https://4byte.sourcify.dev.
FourByteEvent
Get the event signature for a given topic 0 from https://4byte.sourcify.dev.
UploadSignature
Upload the given signatures to https://4byte.sourcify.dev.
Example inputs:
- “transfer(address,uint256)”
- “function transfer(address,uint256)”
- “function transfer(address,uint256)” “event Transfer(address,address,uint256)”
- “./out/Contract.sol/Contract.json”
Fields
PrettyCalldata
Pretty print calldata.
Tries to decode the calldata using https://4byte.sourcify.dev unless –offline is passed.
Fields
offline: boolSkip the https://4byte.sourcify.dev lookup.
CreationCode(CreationCodeArgs)
Download a contract creation code from Etherscan and RPC.
Artifact(ArtifactArgs)
Generate an artifact file, that can be used to deploy a contract locally.
ConstructorArgs(ConstructorArgsArgs)
Display constructor arguments used for the contract initialization.
Interface(InterfaceArgs)
Generate a Solidity interface from a given ABI
Currently does not support ABI encoder v2.
Examples:
- cast interface $TOKEN –etherscan-api-key $KEY (fetch the ABI from Etherscan)
- cast interface ./out/Counter.sol/Counter.json (load a local ABI file)
Bind(BindArgs)
Generate a rust binding from a given ABI.
B2EPayload(B2EPayloadArgs)
Convert Beacon payload to execution payload.
Sig
Get the selector for a function
Examples:
- cast sig “transfer(address,uint256)”
- cast sig “deposit(uint256)” 2 (optimize for 2 leading zero bytes)