pub enum CastSubcommand {
Show 118 variants
MaxInt {
type: String,
},
MinInt {
type: String,
},
MaxUint {
type: String,
},
AddressZero,
HashZero,
FromUtf8 {
text: Option<String>,
},
ConcatHex {
data: Vec<String>,
},
FromBin,
ToHexdata {
input: Option<String>,
},
ToCheckSumAddress {
address: Option<Address>,
chain_id: Option<u64>,
},
ToAscii {
hexdata: Option<String>,
},
ToUtf8 {
hexdata: Option<String>,
},
FromFixedPoint {
decimals: Option<String>,
value: Option<String>,
},
ToBytes32 {
bytes: Option<String>,
},
ToBytesMemory {
data: Option<String>,
},
Pad {
data: Option<String>,
right: bool,
left: bool,
len: usize,
},
ToFixedPoint {
decimals: Option<String>,
value: Option<String>,
},
ToUint256 {
value: Option<String>,
},
ToInt256 {
value: Option<String>,
},
LeftShift {
value: String,
bits: String,
base_in: Option<String>,
base_out: String,
},
RightShift {
value: String,
bits: String,
base_in: Option<String>,
base_out: String,
},
ToUnit {
value: Option<String>,
unit: String,
},
ParseUnits {
value: Option<String>,
unit: u8,
},
FormatUnits {
value: Option<String>,
unit: u8,
},
ToWei {
value: Option<String>,
unit: String,
},
FromWei {
value: Option<String>,
unit: String,
},
ToRlp {
value: Option<String>,
},
FromRlp {
value: Option<String>,
as_int: bool,
},
ToHex(ToBaseArgs),
ToDec(ToBaseArgs),
ToBase {
base: ToBaseArgs,
base_out: Option<String>,
},
AccessList(AccessListArgs),
Logs(LogsArgs),
Events(EventsArgs),
Block {
block: Option<BlockId>,
fields: Vec<String>,
raw: bool,
full: bool,
rpc: RpcOpts,
network: Option<NetworkVariant>,
},
BlockNumber {
block: Option<BlockId>,
rpc: RpcOpts,
},
Call(CallArgs),
CalldataEncode {
sig: String,
args: Vec<String>,
file: Option<PathBuf>,
},
Chain {
rpc: RpcOpts,
},
ChainId {
rpc: RpcOpts,
},
Client {
rpc: RpcOpts,
},
ComputeAddress {
address: Option<Address>,
nonce: Option<u64>,
salt: Option<B256>,
init_code: Option<String>,
init_code_hash: Option<B256>,
rpc: RpcOpts,
},
Disassemble {
bytecode: Option<String>,
},
MakeTx(MakeTxArgs),
Classify {
raw_tx: Option<String>,
},
Namehash {
name: Option<String>,
},
Tx {
tx_hash: Option<String>,
from: Option<NameOrAddress>,
nonce: Option<u64>,
field: Option<String>,
raw: bool,
lane: bool,
rpc: RpcOpts,
to_request: bool,
network: Option<NetworkVariant>,
},
Receipt {
tx_hash: String,
field: Option<String>,
confirmations: u64,
cast_async: bool,
rpc: RpcOpts,
},
SendTx(SendTxArgs),
BatchMakeTx(BatchMakeTxArgs),
BatchSend(BatchSendArgs),
PublishTx {
raw_tx: String,
cast_async: bool,
rpc: RpcOpts,
},
Estimate(EstimateArgs),
DecodeCalldata {
sig: String,
calldata: Option<String>,
file: Option<PathBuf>,
},
DecodeString {
data: String,
},
DecodeEvent {
sig: Option<String>,
data: String,
},
DecodeError {
sig: Option<String>,
data: String,
},
DecodeAbi {
sig: String,
calldata: String,
input: bool,
},
AbiEncode {
sig: String,
packed: bool,
args: Vec<String>,
},
AbiEncodeEvent {
sig: String,
args: Vec<String>,
},
Index {
key_type: String,
key: String,
slot_number: String,
},
IndexErc7201 {
id: Option<String>,
formula_id: String,
},
Implementation {
block: Option<BlockId>,
beacon: bool,
who: NameOrAddress,
rpc: RpcOpts,
},
Admin {
block: Option<BlockId>,
who: NameOrAddress,
rpc: RpcOpts,
},
FourByte {
selector: Option<Selector>,
},
FourByteCalldata {
calldata: Option<String>,
},
FourByteEvent {
topic: Option<B256>,
},
UploadSignature {
signatures: Vec<String>,
},
PrettyCalldata {
calldata: Option<String>,
offline: bool,
},
Age {
block: Option<BlockId>,
rpc: RpcOpts,
},
Balance {
block: Option<BlockId>,
who: NameOrAddress,
ether: bool,
rpc: RpcOpts,
erc20: Option<Address>,
overrides: CallOverrideOpts,
},
BaseFee {
block: Option<BlockId>,
rpc: RpcOpts,
},
Code {
block: Option<BlockId>,
who: NameOrAddress,
disassemble: bool,
rpc: RpcOpts,
},
Codesize {
block: Option<BlockId>,
who: NameOrAddress,
rpc: RpcOpts,
},
GasPrice {
rpc: RpcOpts,
},
SigEvent {
event_string: Option<String>,
},
Keccak {
data: Option<String>,
},
HashMessage {
message: Option<String>,
},
ResolveName {
who: Option<String>,
verify: bool,
rpc: RpcOpts,
},
LookupAddress {
who: Option<Address>,
verify: bool,
rpc: RpcOpts,
},
Storage(StorageArgs),
Proof {
address: NameOrAddress,
slots: Vec<B256>,
block: Option<BlockId>,
rpc: RpcOpts,
},
Nonce {
block: Option<BlockId>,
who: NameOrAddress,
rpc: RpcOpts,
},
Codehash {
block: Option<BlockId>,
who: NameOrAddress,
slots: Vec<B256>,
rpc: RpcOpts,
},
StorageRoot {
block: Option<BlockId>,
who: NameOrAddress,
slots: Vec<B256>,
rpc: RpcOpts,
},
ChannelId {
payer: NameOrAddress,
payee: NameOrAddress,
token: NameOrAddress,
salt: B256,
operator: Option<NameOrAddress>,
authorized_signer: Option<NameOrAddress>,
expiring_nonce_hash: B256,
reserve: Option<NameOrAddress>,
block: Option<BlockId>,
rpc: RpcOpts,
},
Source {
address: String,
flatten: bool,
directory: Option<PathBuf>,
etherscan: EtherscanOpts,
explorer_api_url: Option<String>,
explorer_url: Option<String>,
},
Wallet {
command: WalletSubcommands,
},
CreationCode(CreationCodeArgs),
Artifact(ArtifactArgs),
ConstructorArgs(ConstructorArgsArgs),
Interface(InterfaceArgs),
Bind(BindArgs),
B2EPayload(B2EPayloadArgs),
Sig {
sig: Option<String>,
optimize: Option<usize>,
},
Create2(Create2Args),
FindBlock(FindBlockArgs),
Completions {
shell: Shell,
},
Run(RunArgs),
Rpc(RpcArgs),
FormatBytes32String {
string: Option<String>,
},
ParseBytes32String {
bytes: Option<String>,
},
ParseBytes32Address {
bytes: Option<String>,
},
DecodeTransaction {
tx: Option<String>,
network: Option<NetworkVariant>,
},
RecoverAuthority {
auth: String,
},
Selectors {
bytecode: Option<String>,
resolve: bool,
},
TxPool {
command: TxPoolSubcommands,
},
DAEstimate(DAEstimateArgs),
Erc20Token {
command: Erc20Subcommand,
},
Tip20Token {
command: Tip20Subcommand,
},
ReceivePolicy {
command: ReceivePolicySubcommand,
},
Tip403 {
command: Tip403Subcommand,
},
StorageCredits {
command: StorageCreditsSubcommand,
},
Keychain {
command: KeychainSubcommand,
},
KeyAuthorization {
command: KeyAuthorizationSubcommand,
},
Tempo {
command: TempoSubcommand,
},
VirtualAddress {
command: VaddrSubcommand,
},
Trace(TraceArgs),
}Variants
MaxInt
Prints the maximum value of the given integer type.
MinInt
Prints the minimum value of the given integer type.
MaxUint
Prints the maximum value of the given integer type.
AddressZero
Prints the zero address.
HashZero
Prints the zero hash.
FromUtf8
Convert UTF8 text to hex.
ConcatHex
Concatenate hex strings.
FromBin
Convert binary data into hex data.
ToHexdata
Normalize the input to lowercase, 0x-prefixed hex.
The input can be:
- mixed case hex with or without 0x prefix
- 0x prefixed hex, concatenated with a ‘:’
- an absolute path to file
- @tag, where the tag is defined in an environment variable
ToCheckSumAddress
Convert an address to a checksummed format (EIP-55).
Fields
ToAscii
Convert hex data to an ASCII string.
ToUtf8
Convert hex data to a utf-8 string.
FromFixedPoint
Convert a fixed point number into an integer.
Fields
ToBytes32
Right-pads hex data to 32 bytes.
ToBytesMemory
Convert hex data to the word-aligned layout of a Solidity bytes memory value.
The output contains a 32-byte length prefix followed by the data, right-padded with zeros to a whole number of 32-byte words.
Pad
Pads hex data to a specified length.
Fields
ToFixedPoint
Convert an integer into a fixed point number.
Fields
ToUint256
Convert a number to a hex-encoded uint256.
ToInt256
Convert a number to a hex-encoded int256.
LeftShift
Perform a left shifting operation
Fields
RightShift
Perform a right shifting operation
Fields
ToUnit
Convert an ETH amount into another unit (ether, gwei or wei)
Examples:
- 1ether wei
- “1 ether” wei
- 1ether
- 1 gwei
- 1gwei ether
Fields
ParseUnits
Convert a number from decimal to smallest unit with arbitrary decimals
Examples:
- 1.0 6 (for USDC, result: 1000000)
- 2.5 12 (for 12 decimals token, result: 2500000000000)
- 1.23 3 (for 3 decimals token, result: 1230)
FormatUnits
Format a number from smallest unit to decimal with arbitrary decimals
Examples:
- 1000000 6 (for USDC, result: 1.0)
- 2500000000000 12 (for 12 decimals, result: 2.5)
- 1230 3 (for 3 decimals, result: 1.23)
ToWei
Convert an ETH amount to wei.
Consider using –to-unit.
Fields
FromWei
Convert wei into an ETH amount.
Consider using –to-unit.
Fields
ToRlp
RLP encodes hex data, or an array of hex data
Accepts a hex-encoded string, or an array of hex-encoded strings. Can be arbitrarily recursive.
Examples:
cast to-rlp "[]"->0xc0cast to-rlp "0x22"->0x22cast to-rlp "[\"0x61\"]"->0xc161cast to-rlp "[\"0xf1\", \"f2\"]"->0xc481f181f2
Fields
FromRlp
Decodes RLP hex-encoded data.
ToHex(ToBaseArgs)
Converts a number of one base to another
ToDec(ToBaseArgs)
Converts a number of one base to decimal
ToBase
Converts a number of one base to another
AccessList(AccessListArgs)
Create an access list for a transaction
Examples:
- cast access-list vitalik.eth –value 0.1ether
- cast access-list $TOKEN “transfer(address,uint256)” vitalik.eth 100
Logs(LogsArgs)
Get logs by signature or topic
Examples:
- cast logs “Transfer(address indexed from, address indexed to, uint256 value)”
- cast logs –address $TOKEN –from-block 21000000 –to-block latest $TOPIC_0
Events(EventsArgs)
Fetch and decode events from a transaction receipt or log filter.
Examples:
- cast events $TX_HASH
- cast events –tx-hash $TX_HASH
- cast events –address $TOKEN –from-block 21000000 –to-block latest
- cast events –address $TOKEN “Transfer(address indexed,address indexed,uint256)”
A lone 32-byte positional value is treated as a transaction hash. Qualify a raw topic with an address, block range, additional topic, or query size.
Block
Get information about a block
Examples:
- cast block latest
- cast block 21000000 –field timestamp
- cast block latest –json
Fields
block: Option<BlockId>The block height to query at.
Can also be the tags earliest, finalized, safe, latest, or pending.
network: Option<NetworkVariant>Specify the Network for correct encoding.
BlockNumber
Get the latest block number.
Fields
Call(CallArgs)
Perform a call on an account without publishing a transaction
Examples:
- cast call $TOKEN “balanceOf(address)(uint256)” vitalik.eth
- cast call $TOKEN “transfer(address,uint256)” vitalik.eth 100 –trace
CalldataEncode
ABI-encode a function with arguments.
Fields
Chain
Get the symbolic name of the current chain.
ChainId
Get the Ethereum chain ID.
Client
Get the current client version.
ComputeAddress
Compute the contract address from a given nonce and deployer address.
Fields
Disassemble
Disassembles a hex-encoded bytecode into a human-readable representation.
MakeTx(MakeTxArgs)
Build and sign a transaction
Examples:
- cast mktx vitalik.eth –value 0.1ether –private-key $PK
- cast mktx $TOKEN “transfer(address,uint256)” vitalik.eth 100 –account dev
Classify
Classify a raw transaction as Tempo T5 payment/general lane.
Namehash
Calculate the ENS namehash of a name.
Tx
Get information about a transaction
Examples:
- cast tx $TX_HASH
- cast tx $TX_HASH blockNumber (only print the blockNumber field)
- cast tx $TX_HASH –raw
Fields
field: Option<String>If specified, only get the given field of the transaction. If “raw”, the RLP encoded transaction will be printed.
to_request: boolIf specified, the transaction will be converted to a TransactionRequest JSON format.
network: Option<NetworkVariant>Specify the Network for correct encoding.
Receipt
Get the transaction receipt for a transaction
Examples:
- cast receipt $TX_HASH
- cast receipt $TX_HASH status (only print the status field)
Fields
SendTx(SendTxArgs)
Sign and publish a transaction
Examples:
- cast send vitalik.eth –value 0.1ether –private-key $PK (transfer ETH)
- cast send $TOKEN “transfer(address,uint256)” vitalik.eth 100 –account dev
- cast send –private-key $PK –create $BYTECODE (deploy a contract)
BatchMakeTx(BatchMakeTxArgs)
Build and sign a batch transaction (Tempo).
BatchSend(BatchSendArgs)
Sign and publish a batch transaction (Tempo).
PublishTx
Publish a raw transaction to the network.
Fields
Estimate(EstimateArgs)
Estimate the gas cost of a transaction
Examples:
- cast estimate vitalik.eth –value 0.1ether
- cast estimate $CONTRACT “deposit()” –value 1ether
DecodeCalldata
Decode ABI-encoded input data
Similar to abi-decode --input, but function selector MUST be prefixed in calldata.
Examples:
- cast decode-calldata “transfer(address,uint256)” $CALLDATA
- cast decode-calldata –json “transfer(address,uint256)” $CALLDATA
Fields
DecodeString
Decode ABI-encoded string.
Similar to calldata-decode --input, but the function argument is a string
DecodeEvent
Decode event data
Examples:
- cast decode-event –sig “Transfer(address,address,uint256)” $DATA
- cast decode-event $DATA (topic0-prefixed data; looks up the signature)
Fields
sig: Option<String>The event signature. If none provided then tries to decode from local cache or https://api.openchain.xyz.
DecodeError
Decode custom error data.
Fields
sig: Option<String>The error signature. If none provided then tries to decode from local cache or https://api.openchain.xyz.
DecodeAbi
Decode ABI-encoded input or output data
Defaults to decoding output data. To decode input data pass –input.
When passing --input, function selector must NOT be prefixed in calldata string.
Examples:
- cast decode-abi “balanceOf(address)(uint256)” $DATA
- cast decode-abi –input “transfer(address,uint256)” $CALLDATA
Fields
AbiEncode
ABI encode the given function argument, excluding the selector
Examples:
- cast abi-encode “transfer(address,uint256)” $ADDRESS 100
- cast abi-encode –packed “f(string,uint64)” hello 100
Fields
AbiEncodeEvent
ABI encode an event and its arguments to generate topics and data.
Index
Compute the storage slot for an entry in a mapping.
Fields
IndexErc7201
Compute storage slots as specified by ERC-7201: Namespaced Storage Layout.
Fields
Implementation
Fetch the EIP-1967 implementation for a contract Can read from the implementation slot or the beacon slot.
Fields
block: Option<BlockId>The block height to query at.
Can also be the tags earliest, finalized, safe, latest, or pending.
beacon: boolFetch the implementation from the beacon slot.
If not specified, the implementation slot is used.
who: NameOrAddressThe address for which the implementation will be fetched.
Admin
Fetch the EIP-1967 admin account
Fields
block: Option<BlockId>The block height to query at.
Can also be the tags earliest, finalized, safe, latest, or pending.
who: NameOrAddressThe address from which the admin account will be fetched.
FourByte
Get the function signatures for the given selector from https://openchain.xyz.
FourByteCalldata
Decode ABI-encoded calldata using https://openchain.xyz.
FourByteEvent
Get the event signature for a given topic 0 from https://openchain.xyz.
UploadSignature
Upload the given signatures to https://openchain.xyz.
Example inputs:
- “transfer(address,uint256)”
- “function transfer(address,uint256)”
- “function transfer(address,uint256)” “event Transfer(address,address,uint256)”
- “./out/Contract.sol/Contract.json”
Fields
PrettyCalldata
Pretty print calldata.
Tries to decode the calldata using https://openchain.xyz unless –offline is passed.
Age
Get the timestamp of a block.
Fields
Balance
Get the balance of an account in wei
Examples:
- cast balance vitalik.eth –ether
- cast balance vitalik.eth –erc20 0x6B175474E89094C44Da98b954EedeAC495271d0F
Fields
block: Option<BlockId>The block height to query at.
Can also be the tags earliest, finalized, safe, latest, or pending.
who: NameOrAddressThe account to query.
erc20: Option<Address>erc20 address to query, with the method balanceOf(address) return (uint256), alias
with ‘–erc721’
overrides: CallOverrideOptsBaseFee
Get the basefee of a block.
Fields
Code
Get the runtime bytecode of a contract
Examples:
- cast code 0xC02aaA39b223FE8D0A0e5C4F27eAD9083C756Cc2
- cast code 0xC02aaA39b223FE8D0A0e5C4F27eAD9083C756Cc2 –disassemble
Fields
block: Option<BlockId>The block height to query at.
Can also be the tags earliest, finalized, safe, latest, or pending.
who: NameOrAddressThe contract address.
Codesize
Get the runtime bytecode size of a contract.
Fields
block: Option<BlockId>The block height to query at.
Can also be the tags earliest, finalized, safe, latest, or pending.
who: NameOrAddressThe contract address.
GasPrice
Get the current gas price.
SigEvent
Generate event signatures from event string.
Keccak
Hash arbitrary data using Keccak-256
Examples:
- cast keccak “hello world”
- cast keccak 0xdeadbeef
- echo -n “some data” | cast keccak (hash data from stdin)
HashMessage
Hash a message according to EIP-191.
ResolveName
Perform an ENS lookup.
Fields
LookupAddress
Perform an ENS reverse lookup.
Fields
Storage(StorageArgs)
Get the raw value of a contract’s storage slot
Examples:
- cast storage 0xC02aaA39b223FE8D0A0e5C4F27eAD9083C756Cc2 0
- cast storage $TOKEN –etherscan-api-key $KEY (decode the full storage layout)
Proof
Generate a storage proof for a given storage slot.
Fields
address: NameOrAddressThe contract address.
Nonce
Get the nonce for an account.
Fields
block: Option<BlockId>The block height to query at.
Can also be the tags earliest, finalized, safe, latest, or pending.
who: NameOrAddressThe address to get the nonce for.
Codehash
Get the codehash for an account.
Fields
block: Option<BlockId>The block height to query at.
Can also be the tags earliest, finalized, safe, latest, or pending.
who: NameOrAddressThe address to get the codehash for.
StorageRoot
Get the storage root for an account.
Fields
block: Option<BlockId>The block height to query at.
Can also be the tags earliest, finalized, safe, latest, or pending.
who: NameOrAddressThe address to get the storage root for.
ChannelId
Compute a Tempo TIP-20 channel reserve channel ID.
Fields
payer: NameOrAddressChannel payer address.
payee: NameOrAddressChannel payee address.
token: NameOrAddressTIP-20 token address locked by the channel.
Optional voucher signer. Defaults to the zero address, meaning the payer signs.
Get the source code of a contract from a block explorer.
Fields
etherscan: EtherscanOptsWallet
Wallet management utilities.
Fields
command: WalletSubcommandsCreationCode(CreationCodeArgs)
Download a contract creation code from Etherscan and RPC.
Artifact(ArtifactArgs)
Generate an artifact file, that can be used to deploy a contract locally.
ConstructorArgs(ConstructorArgsArgs)
Display constructor arguments used for the contract initialization.
Interface(InterfaceArgs)
Generate a Solidity interface from a given ABI
Currently does not support ABI encoder v2.
Examples:
- cast interface $TOKEN –etherscan-api-key $KEY (fetch the ABI from Etherscan)
- cast interface ./out/Counter.sol/Counter.json (load a local ABI file)
Bind(BindArgs)
Generate a rust binding from a given ABI.
B2EPayload(B2EPayloadArgs)
Convert Beacon payload to execution payload.
Sig
Get the selector for a function
Examples:
- cast sig “transfer(address,uint256)”
- cast sig “deposit(uint256)” 2 (optimize for 2 leading zero bytes)
Fields
Create2(Create2Args)
Generate a deterministic contract address using CREATE2.
FindBlock(FindBlockArgs)
Get the block number closest to the provided timestamp.
Completions
Generate shell completions script.
Run(RunArgs)
Runs a published transaction in a local environment and prints the trace
Examples:
- cast run $TX_HASH
- cast run $TX_HASH –quick (only use the state from the previous block)
- cast run $TX_HASH –debug (open the transaction in the debugger)
Rpc(RpcArgs)
Perform a raw JSON-RPC request
Examples:
- cast rpc eth_blockNumber
- cast rpc eth_getBlockByNumber 0x123 false
- cast rpc eth_getBlockByNumber ‘[“0x123”, false]’ –raw
FormatBytes32String
Formats a string into bytes32 encoding.
ParseBytes32String
Parses a string from bytes32 encoding.
ParseBytes32Address
DecodeTransaction
Decodes a raw signed EIP 2718 typed transaction
Fields
network: Option<NetworkVariant>Override the network used to decode the transaction.
By default, cast decodes with Foundry’s transaction envelope, which recognizes standard Ethereum txs and Foundry-supported network-specific tx types such as Tempo.
RecoverAuthority
Recovery an EIP-7702 authority from a Authorization JSON string.
Selectors
Extracts function selectors and arguments from bytecode
Fields
resolve: boolResolve the function signatures for the extracted selectors using https://openchain.xyz
TxPool
Inspect the TxPool of a node.
Fields
command: TxPoolSubcommandsDAEstimate(DAEstimateArgs)
optimism only.Estimates the data availability size of a given opstack block.
Erc20Token
ERC20 token operations.
Fields
command: Erc20SubcommandTip20Token
TIP-20 token operations (Tempo).
Fields
command: Tip20SubcommandReceivePolicy
Account-level receive policy operations (Tempo).
Fields
command: ReceivePolicySubcommandTip403
TIP-403 policy registry operations (Tempo).
Fields
command: Tip403SubcommandStorageCredits
T7 storage credits operations (Tempo).
Fields
command: StorageCreditsSubcommandKeychain
Tempo keychain (access key) management.
Fields
command: KeychainSubcommandKeyAuthorization
Tempo key authorization RLP helpers.
Fields
command: KeyAuthorizationSubcommandTempo
Tempo wallet integration (login, etc.).
Fields
command: TempoSubcommandVirtualAddress
TIP-1022 virtual address registry operations (Tempo).
Fields
command: VaddrSubcommandTrace(TraceArgs)