ConversionSubcommand

Enum ConversionSubcommand 

pub enum ConversionSubcommand {
Show 32 variants MaxInt { type: String, }, MinInt { type: String, }, MaxUint { type: String, }, AddressZero, HashZero, FromUtf8 { text: Option<String>, }, ConcatHex { data: Vec<String>, }, FromBin, ToHexdata { input: Option<String>, }, ToCheckSumAddress { address: Option<Address>, chain_id: Option<u64>, }, ToAscii { hexdata: Option<String>, }, ToUtf8 { hexdata: Option<String>, }, FromFixedPoint { decimals: Option<String>, value: Option<String>, }, ToBytes32 { bytes: Option<String>, }, ToBytesMemory { data: Option<String>, }, Pad { data: Option<String>, right: bool, left: bool, len: usize, }, ToFixedPoint { decimals: Option<String>, value: Option<String>, }, ToUint256 { value: Option<String>, }, ToInt256 { value: Option<String>, }, ToUnit { value: Option<String>, unit: String, }, ParseUnits { value: Option<String>, unit: u8, }, FormatUnits { value: Option<String>, unit: u8, }, ToWei { value: Option<String>, unit: String, }, FromWei { value: Option<String>, unit: String, }, ToRlp { value: Option<String>, }, FromRlp { value: Option<String>, as_int: bool, }, ToHex(ToBaseArgs), ToDec(ToBaseArgs), ToBase { base: ToBaseArgs, base_out: Option<String>, }, FormatBytes32String { string: Option<String>, }, ParseBytes32String { bytes: Option<String>, }, ParseBytes32Address { bytes: Option<String>, },
}
Constant and conversion subcommands.

Variants



MaxInt

Prints the maximum value of the given integer type.

Fields

type: String

The integer type to get the maximum value of.



MinInt

Prints the minimum value of the given integer type.

Fields

type: String

The integer type to get the minimum value of.



MaxUint

Prints the maximum value of the given integer type.

Fields

type: String

The unsigned integer type to get the maximum value of.



AddressZero

Prints the zero address.



HashZero

Prints the zero hash.



FromUtf8

Convert UTF8 text to hex.

Fields

text: Option<String>

The text to convert.



ConcatHex

Concatenate hex strings.

Fields

data: Vec<String>

The data to concatenate.



FromBin

Convert binary data into hex data.



ToHexdata

Normalize the input to lowercase, 0x-prefixed hex.

The input can be:

  • mixed case hex with or without 0x prefix
  • 0x prefixed hex, concatenated with a ‘:’
  • an absolute path to file
  • @tag, where the tag is defined in an environment variable

Fields

input: Option<String>

The input to normalize.



ToCheckSumAddress

Convert an address to a checksummed format (EIP-55).

Fields

address: Option<Address>

The address to convert.

chain_id: Option<u64>

EIP-155 chain ID to encode the address using EIP-1191.



ToAscii

Convert hex data to an ASCII string.

Fields

hexdata: Option<String>

The hex data to convert.



ToUtf8

Convert hex data to a utf-8 string.

Fields

hexdata: Option<String>

The hex data to convert.



FromFixedPoint

Convert a fixed point number into an integer.

Fields

decimals: Option<String>

The number of decimals to use.

value: Option<String>

The value to convert.



ToBytes32

Right-pads hex data to 32 bytes.

Fields

bytes: Option<String>

The hex data to convert.



ToBytesMemory

Convert hex data to the word-aligned layout of a Solidity bytes memory value.

The output contains a 32-byte length prefix followed by the data, right-padded with zeros to a whole number of 32-byte words.

Fields

data: Option<String>

The hex data to convert.



Pad

Pads hex data to a specified length.

Fields

data: Option<String>

The hex data to pad.

right: bool

Right-pad the data (instead of left-pad).

left: bool

Left-pad the data (default).

len: usize

Target length in bytes (default: 32).



ToFixedPoint

Convert an integer into a fixed point number.

Fields

decimals: Option<String>

The number of decimals to use.

value: Option<String>

The value to convert.



ToUint256

Convert a number to a hex-encoded uint256.

Fields

value: Option<String>

The value to convert.



ToInt256

Convert a number to a hex-encoded int256.

Fields

value: Option<String>

The value to convert.



ToUnit

Convert an ETH amount into another unit (ether, gwei or wei)

Examples:

  • 1ether wei
  • “1 ether” wei
  • 1ether
  • 1 gwei
  • 1gwei ether

Fields

value: Option<String>

The value to convert.

unit: String

The unit to convert to (ether, gwei, wei).



ParseUnits

Convert a number from decimal to smallest unit with arbitrary decimals

Examples:

  • 1.0 6 (for USDC, result: 1000000)
  • 2.5 12 (for 12 decimals token, result: 2500000000000)
  • 1.23 3 (for 3 decimals token, result: 1230)

Fields

value: Option<String>

The value to convert.

unit: u8

The unit to convert to.



FormatUnits

Format a number from smallest unit to decimal with arbitrary decimals

Examples:

  • 1000000 6 (for USDC, result: 1.0)
  • 2500000000000 12 (for 12 decimals, result: 2.5)
  • 1230 3 (for 3 decimals, result: 1.23)

Fields

value: Option<String>

The value to format.

unit: u8

The unit to format to.



ToWei

Convert an ETH amount to wei.

Consider using –to-unit.

Fields

value: Option<String>

The value to convert.

unit: String

The unit to convert from (ether, gwei, wei).



FromWei

Convert wei into an ETH amount.

Consider using –to-unit.

Fields

value: Option<String>

The value to convert.

unit: String

The unit to convert from (ether, gwei, wei).



ToRlp

RLP encodes hex data, or an array of hex data

Accepts a hex-encoded string, or an array of hex-encoded strings. Can be arbitrarily recursive.

Examples:

  • cast to-rlp "[]" -> 0xc0
  • cast to-rlp "0x22" -> 0x22
  • cast to-rlp "[\"0x61\"]" -> 0xc161
  • cast to-rlp "[\"0xf1\", \"f2\"]" -> 0xc481f181f2

Fields

value: Option<String>

The value to convert.

This is a hex-encoded string, or an array of hex-encoded strings. Can be arbitrarily recursive.



FromRlp

Decodes RLP hex-encoded data.

Fields

value: Option<String>

The RLP hex-encoded data.

as_int: bool

Decode the RLP data as int



ToHex(ToBaseArgs)

Converts a number of one base to another



ToDec(ToBaseArgs)

Converts a number of one base to decimal



ToBase

Converts a number of one base to another

Fields

base_out: Option<String>

The output base.



FormatBytes32String

Formats a string into bytes32 encoding.

Fields

string: Option<String>

The string to format.



ParseBytes32String

Parses a string from bytes32 encoding.

Fields

bytes: Option<String>

The string to parse.



ParseBytes32Address

Fields