QuerySubcommand

Enum QuerySubcommand 

pub enum QuerySubcommand {
Show 31 variants AccessList(AccessListArgs), Block { block: Option<BlockId>, fields: Vec<String>, raw: bool, full: bool, rpc: RpcOpts, network: Option<NetworkVariant>, }, BlockNumber { block: Option<BlockId>, rpc: RpcOpts, }, Bal(BalArgs), Chain { rpc: RpcOpts, }, ChainId { rpc: RpcOpts, }, Client { rpc: RpcOpts, }, ComputeAddress { address: Option<Address>, nonce: Option<u64>, salt: Option<B256>, init_code: Option<String>, init_code_hash: Option<B256>, rpc: RpcOpts, }, Disassemble { bytecode: Option<String>, }, Namehash { name: Option<String>, }, Index { key_type: String, key: String, slot_number: String, }, IndexErc7201 { id: Option<String>, formula_id: String, }, Implementation { block: Option<BlockId>, beacon: bool, who: NameOrAddress, rpc: RpcOpts, }, Admin { block: Option<BlockId>, who: NameOrAddress, rpc: RpcOpts, }, Age { block: Option<BlockId>, rpc: RpcOpts, }, Balance { block: Option<BlockId>, who: NameOrAddress, ether: bool, rpc: RpcOpts, erc20: Option<Address>, overrides: CallOverrideOpts, }, BaseFee { block: Option<BlockId>, rpc: RpcOpts, }, Code { block: Option<BlockId>, who: NameOrAddress, disassemble: bool, rpc: RpcOpts, }, Codesize { block: Option<BlockId>, who: NameOrAddress, rpc: RpcOpts, }, GasPrice { rpc: RpcOpts, }, ResolveName { who: Option<String>, verify: bool, rpc: RpcOpts, }, LookupAddress { who: Option<Address>, verify: bool, rpc: RpcOpts, }, Storage(StorageArgs), Proof { address: NameOrAddress, slots: Vec<B256>, block: Option<BlockId>, rpc: RpcOpts, }, Nonce { block: Option<BlockId>, who: NameOrAddress, rpc: RpcOpts, }, Codehash { block: Option<BlockId>, who: NameOrAddress, slots: Vec<B256>, rpc: RpcOpts, }, StorageRoot { block: Option<BlockId>, who: NameOrAddress, slots: Vec<B256>, rpc: RpcOpts, }, ChannelId { payer: NameOrAddress, payee: NameOrAddress, token: NameOrAddress, salt: B256, operator: Option<NameOrAddress>, authorized_signer: Option<NameOrAddress>, expiring_nonce_hash: B256, reserve: Option<NameOrAddress>, block: Option<BlockId>, rpc: RpcOpts, }, FindBlock(FindBlockArgs), Rpc(RpcArgs), Selectors { bytecode: Option<String>, resolve: bool, },
}
Blockchain, RPC and ENS query subcommands.

Variants



AccessList(AccessListArgs)

Create an access list for a transaction

Examples:

  • cast access-list vitalik.eth –value 0.1ether
  • cast access-list $TOKEN “transfer(address,uint256)” vitalik.eth 100


Block

Get information about a block

Examples:

  • cast block latest
  • cast block 21000000 –field timestamp
  • cast block latest –json

Fields

block: Option<BlockId>

The block height to query at.

Can also be the tags earliest, finalized, safe, latest, or pending.

fields: Vec<String>

If specified, only get the given field of the block.

raw: bool

Print the raw RLP encoded block header.

full: bool
network: Option<NetworkVariant>

Specify the Network for correct encoding.



BlockNumber

Get the latest block number.

Fields

block: Option<BlockId>

The hash or tag to query. If not specified, the latest number is returned.



Bal(BalArgs)

Get the EIP-7928 block access list of a block

Examples:

  • cast bal latest
  • cast bal 21000000 –raw


Chain

Get the symbolic name of the current chain.

Fields



ChainId

Get the Ethereum chain ID.

Fields



Client

Get the current client version.

Fields



ComputeAddress

Compute the contract address from a given nonce and deployer address.

Fields

address: Option<Address>

The deployer address.

nonce: Option<u64>

The nonce of the deployer address.

salt: Option<B256>

The salt for CREATE2 address computation.

init_code: Option<String>

The init code for CREATE2 address computation.

init_code_hash: Option<B256>

The init code hash for CREATE2 address computation.



Disassemble

Disassembles a hex-encoded bytecode into a human-readable representation.

Fields

bytecode: Option<String>

The hex-encoded bytecode.



Namehash

Calculate the ENS namehash of a name.

Fields



Index

Compute the storage slot for an entry in a mapping.

Fields

key_type: String

The mapping key type.

key: String

The mapping key.

slot_number: String

The storage slot of the mapping.



IndexErc7201

Compute storage slots as specified by ERC-7201: Namespaced Storage Layout.

Fields

id: Option<String>

The arbitrary identifier.

formula_id: String

The formula ID. Currently the only supported formula is erc7201.



Implementation

Fetch the EIP-1967 implementation for a contract Can read from the implementation slot or the beacon slot.

Fields

block: Option<BlockId>

The block height to query at.

Can also be the tags earliest, finalized, safe, latest, or pending.

beacon: bool

Fetch the implementation from the beacon slot.

If not specified, the implementation slot is used.

who: NameOrAddress

The address for which the implementation will be fetched.



Admin

Fetch the EIP-1967 admin account

Fields

block: Option<BlockId>

The block height to query at.

Can also be the tags earliest, finalized, safe, latest, or pending.

who: NameOrAddress

The address from which the admin account will be fetched.



Age

Get the timestamp of a block.

Fields

block: Option<BlockId>

The block height to query at.

Can also be the tags earliest, finalized, safe, latest, or pending.



Balance

Get the balance of an account in wei

Examples:

  • cast balance vitalik.eth –ether
  • cast balance vitalik.eth –erc20 0x6B175474E89094C44Da98b954EedeAC495271d0F

Fields

block: Option<BlockId>

The block height to query at.

Can also be the tags earliest, finalized, safe, latest, or pending.

who: NameOrAddress

The account to query.

ether: bool

Format the balance in ether.

erc20: Option<Address>

erc20 address to query, with the method balanceOf(address) return (uint256), alias with ‘–erc721’



BaseFee

Get the basefee of a block.

Fields

block: Option<BlockId>

The block height to query at.

Can also be the tags earliest, finalized, safe, latest, or pending.



Code

Get the runtime bytecode of a contract

Examples:

  • cast code 0xC02aaA39b223FE8D0A0e5C4F27eAD9083C756Cc2
  • cast code 0xC02aaA39b223FE8D0A0e5C4F27eAD9083C756Cc2 –disassemble

Fields

block: Option<BlockId>

The block height to query at.

Can also be the tags earliest, finalized, safe, latest, or pending.

who: NameOrAddress

The contract address.

disassemble: bool

Disassemble bytecodes.



Codesize

Get the runtime bytecode size of a contract.

Fields

block: Option<BlockId>

The block height to query at.

Can also be the tags earliest, finalized, safe, latest, or pending.

who: NameOrAddress

The contract address.



GasPrice

Get the current gas price.

Fields



ResolveName

Perform an ENS lookup.

Fields

who: Option<String>

The name to lookup.

verify: bool

Perform a reverse lookup to verify that the name is correct.



LookupAddress

Perform an ENS reverse lookup.

Fields

who: Option<Address>

The account to perform the lookup for.

verify: bool

Perform a normal lookup to verify that the address is correct.



Storage(StorageArgs)

Get the raw value of a contract’s storage slot

Examples:

  • cast storage 0xC02aaA39b223FE8D0A0e5C4F27eAD9083C756Cc2 0
  • cast storage $TOKEN –etherscan-api-key $KEY (decode the full storage layout)


Proof

Generate a storage proof for a given storage slot.

Fields

address: NameOrAddress

The contract address.

slots: Vec<B256>

The storage slot numbers (hex or decimal).

block: Option<BlockId>

The block height to query at.

Can also be the tags earliest, finalized, safe, latest, or pending.



Nonce

Get the nonce for an account.

Fields

block: Option<BlockId>

The block height to query at.

Can also be the tags earliest, finalized, safe, latest, or pending.

who: NameOrAddress

The address to get the nonce for.



Codehash

Get the codehash for an account.

Fields

block: Option<BlockId>

The block height to query at.

Can also be the tags earliest, finalized, safe, latest, or pending.

who: NameOrAddress

The address to get the codehash for.

slots: Vec<B256>

The storage slot numbers (hex or decimal).



StorageRoot

Get the storage root for an account.

Fields

block: Option<BlockId>

The block height to query at.

Can also be the tags earliest, finalized, safe, latest, or pending.

who: NameOrAddress

The address to get the storage root for.

slots: Vec<B256>

The storage slot numbers (hex or decimal).



ChannelId

Compute a Tempo TIP-20 channel reserve channel ID.

Fields

payer: NameOrAddress

Channel payer address.

payee: NameOrAddress

Channel payee address.

token: NameOrAddress

TIP-20 token address locked by the channel.

salt: B256

User-supplied channel salt.

operator: Option<NameOrAddress>

Optional relayer allowed to submit settlements for the payee.

authorized_signer: Option<NameOrAddress>

Optional voucher signer. Defaults to the zero address, meaning the payer signs.

expiring_nonce_hash: B256

Transaction-derived expiring nonce hash from ChannelOpened.

reserve: Option<NameOrAddress>

Channel reserve precompile address.

block: Option<BlockId>

The block height to query at.

Can also be the tags earliest, finalized, safe, latest, or pending.



FindBlock(FindBlockArgs)

Get the block number closest to the provided timestamp.



Rpc(RpcArgs)

Perform a raw JSON-RPC request

Examples:

  • cast rpc eth_blockNumber
  • cast rpc eth_getBlockByNumber 0x123 false
  • cast rpc eth_getBlockByNumber ‘[“0x123”, false]’ –raw


Selectors

Extracts function selectors and arguments from bytecode

Fields

bytecode: Option<String>

The hex-encoded bytecode.

resolve: bool

Resolve the function signatures for the extracted selectors using https://4byte.sourcify.dev