pub enum TransactionSubcommand {
Call(CallArgs),
MakeTx(MakeTxArgs),
Classify {
raw_tx: Option<String>,
},
Tx {
tx_hash: Option<String>,
from: Option<NameOrAddress>,
nonce: Option<u64>,
field: Option<String>,
raw: bool,
lane: bool,
rpc: RpcOpts,
to_request: bool,
network: Option<NetworkVariant>,
},
Receipt {
tx_hash: String,
field: Option<String>,
confirmations: u64,
cast_async: bool,
rpc: RpcOpts,
},
SendTx(SendTxArgs),
BatchMakeTx(BatchMakeTxArgs),
BatchSend(BatchSendArgs),
PublishTx {
raw_tx: String,
cast_async: bool,
rpc: RpcOpts,
},
Estimate(EstimateArgs),
Run(RunArgs),
}Expand description
Call and transaction subcommands.
Variants
Call(CallArgs)
Perform a call on an account without publishing a transaction
Examples:
- cast call $TOKEN “balanceOf(address)(uint256)” vitalik.eth
- cast call $TOKEN “transfer(address,uint256)” vitalik.eth 100 –trace
MakeTx(MakeTxArgs)
Build and sign a transaction
Examples:
- cast mktx vitalik.eth –value 0.1ether –private-key $PK
- cast mktx $TOKEN “transfer(address,uint256)” vitalik.eth 100 –account dev
Classify
Classify a raw transaction as Tempo T5 payment/general lane.
Tx
Get information about a transaction
Examples:
- cast tx $TX_HASH
- cast tx $TX_HASH blockNumber (only print the blockNumber field)
- cast tx $TX_HASH –raw
Fields
field: Option<String>If specified, only get the given field of the transaction. If “raw”, the RLP encoded transaction will be printed.
to_request: boolIf specified, the transaction will be converted to a TransactionRequest JSON format.
network: Option<NetworkVariant>Specify the Network for correct encoding.
Receipt
Get the transaction receipt for a transaction
Examples:
- cast receipt $TX_HASH
- cast receipt $TX_HASH status (only print the status field)
Fields
SendTx(SendTxArgs)
Sign and publish a transaction
Examples:
- cast send vitalik.eth –value 0.1ether –private-key $PK (transfer ETH)
- cast send $TOKEN “transfer(address,uint256)” vitalik.eth 100 –account dev
- cast send –private-key $PK –create $BYTECODE (deploy a contract)
BatchMakeTx(BatchMakeTxArgs)
Build and sign a batch transaction (Tempo).
BatchSend(BatchSendArgs)
Sign and publish a batch transaction (Tempo).
PublishTx
Publish a raw transaction to the network.
Fields
Estimate(EstimateArgs)
Estimate the gas cost of a transaction
Examples:
- cast estimate vitalik.eth –value 0.1ether
- cast estimate $CONTRACT “deposit()” –value 1ether
Run(RunArgs)
Runs a published transaction in a local environment and prints the trace
If the node serves an EIP-7928 block access list (BAL) for the transaction’s block, the
transaction’s prestate is read from it instead of replaying the earlier transactions of
the block. Pass --no-bal to always replay the block.
Examples:
- cast run $TX_HASH
- cast run $TX_HASH –quick (only use the state from the previous block)
- cast run $TX_HASH –debug (open the transaction in the debugger)