pub enum QuerySubcommand {
Show 31 variants
AccessList(AccessListArgs),
Block {
block: Option<BlockId>,
fields: Vec<String>,
raw: bool,
full: bool,
rpc: RpcOpts,
network: Option<NetworkVariant>,
},
BlockNumber {
block: Option<BlockId>,
rpc: RpcOpts,
},
Bal(BalArgs),
Chain {
rpc: RpcOpts,
},
ChainId {
rpc: RpcOpts,
},
Client {
rpc: RpcOpts,
},
ComputeAddress {
address: Option<Address>,
nonce: Option<u64>,
salt: Option<B256>,
init_code: Option<String>,
init_code_hash: Option<B256>,
rpc: RpcOpts,
},
Disassemble {
bytecode: Option<String>,
},
Namehash {
name: Option<String>,
},
Index {
key_type: String,
key: String,
slot_number: String,
},
IndexErc7201 {
id: Option<String>,
formula_id: String,
},
Implementation {
block: Option<BlockId>,
beacon: bool,
who: NameOrAddress,
rpc: RpcOpts,
},
Admin {
block: Option<BlockId>,
who: NameOrAddress,
rpc: RpcOpts,
},
Age {
block: Option<BlockId>,
rpc: RpcOpts,
},
Balance {
block: Option<BlockId>,
who: NameOrAddress,
ether: bool,
rpc: RpcOpts,
erc20: Option<Address>,
overrides: CallOverrideOpts,
},
BaseFee {
block: Option<BlockId>,
rpc: RpcOpts,
},
Code {
block: Option<BlockId>,
who: NameOrAddress,
disassemble: bool,
rpc: RpcOpts,
},
Codesize {
block: Option<BlockId>,
who: NameOrAddress,
rpc: RpcOpts,
},
GasPrice {
rpc: RpcOpts,
},
ResolveName {
who: Option<String>,
verify: bool,
rpc: RpcOpts,
},
LookupAddress {
who: Option<Address>,
verify: bool,
rpc: RpcOpts,
},
Storage(StorageArgs),
Proof {
address: NameOrAddress,
slots: Vec<B256>,
block: Option<BlockId>,
rpc: RpcOpts,
},
Nonce {
block: Option<BlockId>,
who: NameOrAddress,
rpc: RpcOpts,
},
Codehash {
block: Option<BlockId>,
who: NameOrAddress,
slots: Vec<B256>,
rpc: RpcOpts,
},
StorageRoot {
block: Option<BlockId>,
who: NameOrAddress,
slots: Vec<B256>,
rpc: RpcOpts,
},
ChannelId {
payer: NameOrAddress,
payee: NameOrAddress,
token: NameOrAddress,
salt: B256,
operator: Option<NameOrAddress>,
authorized_signer: Option<NameOrAddress>,
expiring_nonce_hash: B256,
reserve: Option<NameOrAddress>,
block: Option<BlockId>,
rpc: RpcOpts,
},
FindBlock(FindBlockArgs),
Rpc(RpcArgs),
Selectors {
bytecode: Option<String>,
resolve: bool,
},
}Expand description
Blockchain, RPC and ENS query subcommands.
Variants
AccessList(AccessListArgs)
Create an access list for a transaction
Examples:
- cast access-list vitalik.eth –value 0.1ether
- cast access-list $TOKEN “transfer(address,uint256)” vitalik.eth 100
Block
Get information about a block
Examples:
- cast block latest
- cast block 21000000 –field timestamp
- cast block latest –json
Fields
block: Option<BlockId>The block height to query at.
Can also be the tags earliest, finalized, safe, latest, or pending.
network: Option<NetworkVariant>Specify the Network for correct encoding.
BlockNumber
Get the latest block number.
Fields
Bal(BalArgs)
Get the EIP-7928 block access list of a block
Examples:
- cast bal latest
- cast bal 21000000 –raw
Chain
Get the symbolic name of the current chain.
ChainId
Get the Ethereum chain ID.
Client
Get the current client version.
ComputeAddress
Compute the contract address from a given nonce and deployer address.
Fields
Disassemble
Disassembles a hex-encoded bytecode into a human-readable representation.
Namehash
Calculate the ENS namehash of a name.
Index
Compute the storage slot for an entry in a mapping.
Fields
IndexErc7201
Compute storage slots as specified by ERC-7201: Namespaced Storage Layout.
Fields
Implementation
Fetch the EIP-1967 implementation for a contract Can read from the implementation slot or the beacon slot.
Fields
block: Option<BlockId>The block height to query at.
Can also be the tags earliest, finalized, safe, latest, or pending.
beacon: boolFetch the implementation from the beacon slot.
If not specified, the implementation slot is used.
who: NameOrAddressThe address for which the implementation will be fetched.
Admin
Fetch the EIP-1967 admin account
Fields
block: Option<BlockId>The block height to query at.
Can also be the tags earliest, finalized, safe, latest, or pending.
who: NameOrAddressThe address from which the admin account will be fetched.
Age
Get the timestamp of a block.
Fields
Balance
Get the balance of an account in wei
Examples:
- cast balance vitalik.eth –ether
- cast balance vitalik.eth –erc20 0x6B175474E89094C44Da98b954EedeAC495271d0F
Fields
block: Option<BlockId>The block height to query at.
Can also be the tags earliest, finalized, safe, latest, or pending.
who: NameOrAddressThe account to query.
erc20: Option<Address>erc20 address to query, with the method balanceOf(address) return (uint256), alias
with ‘–erc721’
overrides: CallOverrideOptsBaseFee
Get the basefee of a block.
Fields
Code
Get the runtime bytecode of a contract
Examples:
- cast code 0xC02aaA39b223FE8D0A0e5C4F27eAD9083C756Cc2
- cast code 0xC02aaA39b223FE8D0A0e5C4F27eAD9083C756Cc2 –disassemble
Fields
block: Option<BlockId>The block height to query at.
Can also be the tags earliest, finalized, safe, latest, or pending.
who: NameOrAddressThe contract address.
Codesize
Get the runtime bytecode size of a contract.
Fields
block: Option<BlockId>The block height to query at.
Can also be the tags earliest, finalized, safe, latest, or pending.
who: NameOrAddressThe contract address.
GasPrice
Get the current gas price.
ResolveName
Perform an ENS lookup.
Fields
LookupAddress
Perform an ENS reverse lookup.
Fields
Storage(StorageArgs)
Get the raw value of a contract’s storage slot
Examples:
- cast storage 0xC02aaA39b223FE8D0A0e5C4F27eAD9083C756Cc2 0
- cast storage $TOKEN –etherscan-api-key $KEY (decode the full storage layout)
Proof
Generate a storage proof for a given storage slot.
Fields
address: NameOrAddressThe contract address.
Nonce
Get the nonce for an account.
Fields
block: Option<BlockId>The block height to query at.
Can also be the tags earliest, finalized, safe, latest, or pending.
who: NameOrAddressThe address to get the nonce for.
Codehash
Get the codehash for an account.
Fields
block: Option<BlockId>The block height to query at.
Can also be the tags earliest, finalized, safe, latest, or pending.
who: NameOrAddressThe address to get the codehash for.
StorageRoot
Get the storage root for an account.
Fields
block: Option<BlockId>The block height to query at.
Can also be the tags earliest, finalized, safe, latest, or pending.
who: NameOrAddressThe address to get the storage root for.
ChannelId
Compute a Tempo TIP-20 channel reserve channel ID.
Fields
payer: NameOrAddressChannel payer address.
payee: NameOrAddressChannel payee address.
token: NameOrAddressTIP-20 token address locked by the channel.
Optional voucher signer. Defaults to the zero address, meaning the payer signs.
FindBlock(FindBlockArgs)
Get the block number closest to the provided timestamp.
Rpc(RpcArgs)
Perform a raw JSON-RPC request
Examples:
- cast rpc eth_blockNumber
- cast rpc eth_getBlockByNumber 0x123 false
- cast rpc eth_getBlockByNumber ‘[“0x123”, false]’ –raw
Selectors
Extracts function selectors and arguments from bytecode